# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApimodelAppItemV5
from ..models import ApimodelCreateAppV5Request
from ..models import ResponseErrorResponse

from ..operations.app_v5 import CreateAppV5


@same_doc_as(CreateAppV5)
def create_app_v5(
    app: str,
    body: ApimodelCreateAppV5Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create new extend app (v5) (CreateAppV5)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [CREATE]`

    Create new extend app with name provided by {app} path parameter and specified scenario type

    Available scenario:
    - scenario 2: `service-extension`
    - scenario 3: `event-handler`
    - scenario 1: `function-override`


    Available app status:
    - `app-creating`
    - `app-creation-failed`
    - `app-creation-timeout`
    - `app-undeployed`
    - `deployment-in-progress`
    - `deployment-failed`
    - `deployment-timeout`
    - `deployment-running`
    - `deployment-down`
    - `app-stopping`
    - `app-stop-failed`
    - `app-stop-timeout`
    - `app-stopped`
    - `app-removing`
    - `app-removed`
    - `app-remove-timeout`

    Properties:
        url: /csm/v5/admin/namespaces/{namespace}/apps/{app}

        method: POST

        tags: ["App V5"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateAppV5Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppItemV5 (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateAppV5.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateAppV5)
async def create_app_v5_async(
    app: str,
    body: ApimodelCreateAppV5Request,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create new extend app (v5) (CreateAppV5)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [CREATE]`

    Create new extend app with name provided by {app} path parameter and specified scenario type

    Available scenario:
    - scenario 2: `service-extension`
    - scenario 3: `event-handler`
    - scenario 1: `function-override`


    Available app status:
    - `app-creating`
    - `app-creation-failed`
    - `app-creation-timeout`
    - `app-undeployed`
    - `deployment-in-progress`
    - `deployment-failed`
    - `deployment-timeout`
    - `deployment-running`
    - `deployment-down`
    - `app-stopping`
    - `app-stop-failed`
    - `app-stop-timeout`
    - `app-stopped`
    - `app-removing`
    - `app-removed`
    - `app-remove-timeout`

    Properties:
        url: /csm/v5/admin/namespaces/{namespace}/apps/{app}

        method: POST

        tags: ["App V5"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateAppV5Request in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppItemV5 (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateAppV5.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Iam Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import ClientmodelListUpsertModulesRequest
from ...models import RestErrorResponse


class AdminUpdateAvailablePermissionsByModule(Operation):
    """Update or create Client permissions module (AdminUpdateAvailablePermissionsByModule)

    Upserts client available permissions at the module level.
    Only the modules listed in the request are processed - any other existing module is left untouched, so *callers do not need to include unchanged modules*.

    ## Groups update behavior

    For each module in the request, the 'groups' array is the *full desired state* of that module's groups - any existing group whose 'groupId' is omitted is treated as ***removed***.
    If a removed group is currently used by any client, the request will fails with 400 and nothing is saved, unless 'forceDelete=true' query param is passed.

    Properties:
        url: /iam/v3/admin/clientConfig/permissions

        method: PUT

        tags: ["Clients Config V3"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ClientmodelListUpsertModulesRequest in body

        force_delete: (forceDelete) OPTIONAL bool in query

    Responses:
        204: No Content - (Operation succeeded)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)
    """

    # region fields

    _url: str = "/iam/v3/admin/clientConfig/permissions"
    _method: str = "PUT"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    body: ClientmodelListUpsertModulesRequest  # REQUIRED in [body]
    force_delete: bool  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "body": self.get_body_params(),
            "query": self.get_query_params(),
        }

    def get_body_params(self) -> Any:
        if not hasattr(self, "body") or self.body is None:
            return None
        return self.body.to_dict()

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "force_delete"):
            result["forceDelete"] = self.force_delete
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_body(
        self, value: ClientmodelListUpsertModulesRequest
    ) -> AdminUpdateAvailablePermissionsByModule:
        self.body = value
        return self

    def with_force_delete(self, value: bool) -> AdminUpdateAvailablePermissionsByModule:
        self.force_delete = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "body") and self.body:
            result["body"] = self.body.to_dict(include_empty=include_empty)
        elif include_empty:
            result["body"] = ClientmodelListUpsertModulesRequest()
        if hasattr(self, "force_delete") and self.force_delete:
            result["forceDelete"] = bool(self.force_delete)
        elif include_empty:
            result["forceDelete"] = False
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[None, Union[None, HttpResponse, RestErrorResponse]]:
        """Parse the given response.

        204: No Content - (Operation succeeded)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 204:
            return None, None
        if code == 401:
            return None, RestErrorResponse.create_from_dict(content)
        if code == 403:
            return None, RestErrorResponse.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        body: ClientmodelListUpsertModulesRequest,
        force_delete: Optional[bool] = None,
        **kwargs,
    ) -> AdminUpdateAvailablePermissionsByModule:
        instance = cls()
        instance.body = body
        if force_delete is not None:
            instance.force_delete = force_delete
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminUpdateAvailablePermissionsByModule:
        instance = cls()
        if "body" in dict_ and dict_["body"] is not None:
            instance.body = ClientmodelListUpsertModulesRequest.create_from_dict(
                dict_["body"], include_empty=include_empty
            )
        elif include_empty:
            instance.body = ClientmodelListUpsertModulesRequest()
        if "forceDelete" in dict_ and dict_["forceDelete"] is not None:
            instance.force_delete = bool(dict_["forceDelete"])
        elif include_empty:
            instance.force_delete = False
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "body": "body",
            "forceDelete": "force_delete",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "body": True,
            "forceDelete": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ApimodelCreateNoSQLAppDatabaseRequest
from ..models import ApimodelCreateNoSQLDatabaseCredentialRequest
from ..models import ApimodelDeleteNoSQLResourceResponse
from ..models import ApimodelNoSQLAppListResponse
from ..models import ApimodelNoSQLDatabaseCredentialResponse
from ..models import ApimodelNoSQLDatabaseDeleteResponse
from ..models import ApimodelNoSQLDatabaseResponse
from ..models import ApimodelNoSQLResourceResponse
from ..models import ApimodelTunnelInfoResponse
from ..models import NosqlresourceNoSQLResourceConfiguration
from ..models import ResponseErrorResponse

from ..operations.managed_resources import CreateNewNoSQLDatabaseCredentialV2
from ..operations.managed_resources import CreateNoSQLClusterV2
from ..operations.managed_resources import CreateNoSQLDatabaseCredentialV2
from ..operations.managed_resources import CreateNoSQLDatabaseV2
from ..operations.managed_resources import DeleteNoSQLClusterV2
from ..operations.managed_resources import DeleteNoSQLDatabaseV2
from ..operations.managed_resources import GetNoSQLAccessTunnelV2
from ..operations.managed_resources import GetNoSQLAppListV2
from ..operations.managed_resources import GetNoSQLClusterV2
from ..operations.managed_resources import GetNoSQLDatabaseV2
from ..operations.managed_resources import StartNoSQLClusterV2
from ..operations.managed_resources import StopNoSQLClusterV2
from ..operations.managed_resources import UpdateNoSQLClusterV2


@same_doc_as(CreateNewNoSQLDatabaseCredentialV2)
def create_new_no_sql_database_credential_v2(
    app: str,
    body: ApimodelCreateNoSQLDatabaseCredentialRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a new database credential for the customer (CreateNewNoSQLDatabaseCredentialV2)

    Creates a new database credential for the customer. This will soft-delete the old credential and create a new one.

    `acknowledgements.acceptNosqlSecureCredentialHandling` is optional when previously accepted during database creation. Otherwise, it MUST be set to true to proceed with credential creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/credentials

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLDatabaseCredentialRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseCredentialResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNewNoSQLDatabaseCredentialV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateNewNoSQLDatabaseCredentialV2)
async def create_new_no_sql_database_credential_v2_async(
    app: str,
    body: ApimodelCreateNoSQLDatabaseCredentialRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a new database credential for the customer (CreateNewNoSQLDatabaseCredentialV2)

    Creates a new database credential for the customer. This will soft-delete the old credential and create a new one.

    `acknowledgements.acceptNosqlSecureCredentialHandling` is optional when previously accepted during database creation. Otherwise, it MUST be set to true to proceed with credential creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/credentials

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLDatabaseCredentialRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseCredentialResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNewNoSQLDatabaseCredentialV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(CreateNoSQLClusterV2)
def create_no_sql_cluster_v2(
    body: NosqlresourceNoSQLResourceConfiguration,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates NoSQL Cluster (CreateNoSQLClusterV2)

    Provision NoSQL database cluster and instances that can be used by extend apps in game namespace within the studio.
    Only one NoSQL resource can be created for one studio/publisher namespace.

    Provisioning process is done asynchronously, you can check from the `status` field of the resource response.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED NosqlresourceNoSQLResourceConfiguration in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLClusterV2.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateNoSQLClusterV2)
async def create_no_sql_cluster_v2_async(
    body: NosqlresourceNoSQLResourceConfiguration,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates NoSQL Cluster (CreateNoSQLClusterV2)

    Provision NoSQL database cluster and instances that can be used by extend apps in game namespace within the studio.
    Only one NoSQL resource can be created for one studio/publisher namespace.

    Provisioning process is done asynchronously, you can check from the `status` field of the resource response.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED NosqlresourceNoSQLResourceConfiguration in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLClusterV2.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(CreateNoSQLDatabaseCredentialV2)
def create_no_sql_database_credential_v2(
    app: str,
    body: ApimodelCreateNoSQLDatabaseCredentialRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a new database credential for the customer (CreateNoSQLDatabaseCredentialV2)

    Creates a new database credential for the customer. This will soft-delete the old credential and create a new one.

    `acknowledgements.acceptNosqlSecureCredentialHandling` is optional when previously accepted during database creation. Otherwise, it MUST be set to true to proceed with credential creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/crendentials

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLDatabaseCredentialRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseCredentialResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLDatabaseCredentialV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(CreateNoSQLDatabaseCredentialV2)
async def create_no_sql_database_credential_v2_async(
    app: str,
    body: ApimodelCreateNoSQLDatabaseCredentialRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates a new database credential for the customer (CreateNoSQLDatabaseCredentialV2)

    Creates a new database credential for the customer. This will soft-delete the old credential and create a new one.

    `acknowledgements.acceptNosqlSecureCredentialHandling` is optional when previously accepted during database creation. Otherwise, it MUST be set to true to proceed with credential creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/crendentials

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLDatabaseCredentialRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseCredentialResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLDatabaseCredentialV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(CreateNoSQLDatabaseV2)
def create_no_sql_database_v2(
    app: str,
    body: ApimodelCreateNoSQLAppDatabaseRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates NoSQL Database for Extend App (CreateNoSQLDatabaseV2)

    Creates a NoSQL database along with its credentials associated with given extend app. The database will be created in the provisioned NoSQL cluster.

    `acknowledgements.acceptNosqlSecureCredentialHandling` MUST be set to true to proceed with database creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLAppDatabaseRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLDatabaseV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateNoSQLDatabaseV2)
async def create_no_sql_database_v2_async(
    app: str,
    body: ApimodelCreateNoSQLAppDatabaseRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Creates NoSQL Database for Extend App (CreateNoSQLDatabaseV2)

    Creates a NoSQL database along with its credentials associated with given extend app. The database will be created in the provisioned NoSQL cluster.

    `acknowledgements.acceptNosqlSecureCredentialHandling` MUST be set to true to proceed with database creation, indicating the customer accepts the secure credential handling mechanism.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: POST

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelCreateNoSQLAppDatabaseRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = CreateNoSQLDatabaseV2.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteNoSQLClusterV2)
def delete_no_sql_cluster_v2(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete NoSQL Cluster (DeleteNoSQLClusterV2)

    You can only delete the cluster when its status is "available".

    Deleting the cluster will:
    - Remove NoSQL integration.
    - Remove all the data from the NoSQL
    - Remove all the credentials, including the Extend Appâs credentials.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: DELETE

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelDeleteNoSQLResourceResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteNoSQLClusterV2.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteNoSQLClusterV2)
async def delete_no_sql_cluster_v2_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete NoSQL Cluster (DeleteNoSQLClusterV2)

    You can only delete the cluster when its status is "available".

    Deleting the cluster will:
    - Remove NoSQL integration.
    - Remove all the data from the NoSQL
    - Remove all the credentials, including the Extend Appâs credentials.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: DELETE

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelDeleteNoSQLResourceResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteNoSQLClusterV2.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteNoSQLDatabaseV2)
def delete_no_sql_database_v2(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Deletes NoSQL Database for Extend App (DeleteNoSQLDatabaseV2)

    Deletes a NoSQL database and its credentials associated with given extend app and game namespace. The database will be removed from the provisioned NoSQL cluster.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: DELETE

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseDeleteResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteNoSQLDatabaseV2.create(
        app=app,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteNoSQLDatabaseV2)
async def delete_no_sql_database_v2_async(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Deletes NoSQL Database for Extend App (DeleteNoSQLDatabaseV2)

    Deletes a NoSQL database and its credentials associated with given extend app and game namespace. The database will be removed from the provisioned NoSQL cluster.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: DELETE

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseDeleteResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DeleteNoSQLDatabaseV2.create(
        app=app,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetNoSQLAccessTunnelV2)
def get_no_sql_access_tunnel_v2(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Access Tunnel (GetNoSQLAccessTunnelV2)

    Returns the NoSQL access tunnel information for a specified game namespace

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/tunnels

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelTunnelInfoResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLAccessTunnelV2.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetNoSQLAccessTunnelV2)
async def get_no_sql_access_tunnel_v2_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Access Tunnel (GetNoSQLAccessTunnelV2)

    Returns the NoSQL access tunnel information for a specified game namespace

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/tunnels

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelTunnelInfoResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLAccessTunnelV2.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetNoSQLAppListV2)
def get_no_sql_app_list_v2(
    resource_id: str,
    studio_name: str,
    app_name: Optional[str] = None,
    game_namespace: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get List of Extend App using NoSQL (GetNoSQLAppListV2)

    Get List of Extend App using NoSQL database by given studio/publisher namespace and the NoSQL cluster resourceId.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.

    Properties:
        url: /csm/v2/admin/namespaces/{studioName}/nosql/{resourceId}/apps

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        resource_id: (resourceId) REQUIRED str in path

        studio_name: (studioName) REQUIRED str in path

        app_name: (appName) OPTIONAL str in query

        game_namespace: (gameNamespace) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelNoSQLAppListResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    request = GetNoSQLAppListV2.create(
        resource_id=resource_id,
        studio_name=studio_name,
        app_name=app_name,
        game_namespace=game_namespace,
        limit=limit,
        offset=offset,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetNoSQLAppListV2)
async def get_no_sql_app_list_v2_async(
    resource_id: str,
    studio_name: str,
    app_name: Optional[str] = None,
    game_namespace: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get List of Extend App using NoSQL (GetNoSQLAppListV2)

    Get List of Extend App using NoSQL database by given studio/publisher namespace and the NoSQL cluster resourceId.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.

    Properties:
        url: /csm/v2/admin/namespaces/{studioName}/nosql/{resourceId}/apps

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        resource_id: (resourceId) REQUIRED str in path

        studio_name: (studioName) REQUIRED str in path

        app_name: (appName) OPTIONAL str in query

        game_namespace: (gameNamespace) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ApimodelNoSQLAppListResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    request = GetNoSQLAppListV2.create(
        resource_id=resource_id,
        studio_name=studio_name,
        app_name=app_name,
        game_namespace=game_namespace,
        limit=limit,
        offset=offset,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetNoSQLClusterV2)
def get_no_sql_cluster_v2(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Cluster Information (GetNoSQLClusterV2)

    Get NoSQL cluster information returns the NoSQL cluster related information by given studio/publisher namespace.

    `status` field - indicates the NoSQL cluster status:
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLClusterV2.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetNoSQLClusterV2)
async def get_no_sql_cluster_v2_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Cluster Information (GetNoSQLClusterV2)

    Get NoSQL cluster information returns the NoSQL cluster related information by given studio/publisher namespace.

    `status` field - indicates the NoSQL cluster status:
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLClusterV2.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetNoSQLDatabaseV2)
def get_no_sql_database_v2(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Database for Extend App (GetNoSQLDatabaseV2)

    Get a NoSQL database information returns the NoSQL database related information by given game namespace
    and app name.

    `resourceStatus` field - indicates the NoSQL cluster status:
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLDatabaseV2.create(
        app=app,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetNoSQLDatabaseV2)
async def get_no_sql_database_v2_async(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get NoSQL Database for Extend App (GetNoSQLDatabaseV2)

    Get a NoSQL database information returns the NoSQL database related information by given game namespace
    and app name.

    `resourceStatus` field - indicates the NoSQL cluster status:
    - `updating` : The cluster is being modified and is not yet accessible (e.g., updating min/max DCU).
    - `creating` : The cluster or instance is being created and is not yet accessible.
    - `deleting` : The cluster is in the process of being deleted and is not accessible.
    - `failed` : The cluster failed to provision or is in an error state and not accessible.
    - `stopping` : The cluster is in the process of stopping and will soon become inaccessible.
    - `stopped` : The cluster is stopped and not accessible.
    - `starting` : The cluster is transitioning from stopped to running, or is rebooting.
    - `unknown` : The cluster status is not recognized
    - `available` : The cluster is accessible.
    - `maintenance` : The cluster is undergoing maintenance operations and is not accessible.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/apps/{app}/nosql/databases

        method: GET

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLDatabaseResponse (OK)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetNoSQLDatabaseV2.create(
        app=app,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(StartNoSQLClusterV2)
def start_no_sql_cluster_v2(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Start NoSQL Cluster (StartNoSQLClusterV2)

    Start NoSQL cluster.
    You can only start the cluster when its status is "stopped".

    Cluster starting process may take some time to complete.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters/start

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = StartNoSQLClusterV2.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(StartNoSQLClusterV2)
async def start_no_sql_cluster_v2_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Start NoSQL Cluster (StartNoSQLClusterV2)

    Start NoSQL cluster.
    You can only start the cluster when its status is "stopped".

    Cluster starting process may take some time to complete.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters/start

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = StartNoSQLClusterV2.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(StopNoSQLClusterV2)
def stop_no_sql_cluster_v2(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Stop NoSQL Cluster (StopNoSQLClusterV2)

    Stop NoSQL cluster.
    You can only start the cluster when its status is "available".

    Cluster stopping process may take some time to complete.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters/stop

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = StopNoSQLClusterV2.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(StopNoSQLClusterV2)
async def stop_no_sql_cluster_v2_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Stop NoSQL Cluster (StopNoSQLClusterV2)

    Stop NoSQL cluster.
    You can only start the cluster when its status is "available".

    Cluster stopping process may take some time to complete.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters/stop

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = StopNoSQLClusterV2.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateNoSQLClusterV2)
def update_no_sql_cluster_v2(
    body: NosqlresourceNoSQLResourceConfiguration,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update NoSQL Cluster Configurations (UpdateNoSQLClusterV2)

    Update NoSQL cluster configurations such as min/max DCU (Database Capacity Units) for the NoSQL cluster in the given studio/publisher namespace.
    The cluster must be in an available state to allow configuration updates.

    Configuration update process may take some time to complete, you can check the updated status from the `status` field of the resource response.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED NosqlresourceNoSQLResourceConfiguration in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateNoSQLClusterV2.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateNoSQLClusterV2)
async def update_no_sql_cluster_v2_async(
    body: NosqlresourceNoSQLResourceConfiguration,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update NoSQL Cluster Configurations (UpdateNoSQLClusterV2)

    Update NoSQL cluster configurations such as min/max DCU (Database Capacity Units) for the NoSQL cluster in the given studio/publisher namespace.
    The cluster must be in an available state to allow configuration updates.

    Configuration update process may take some time to complete, you can check the updated status from the `status` field of the resource response.

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/nosql/clusters

        method: PUT

        tags: ["Managed Resources"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED NosqlresourceNoSQLResourceConfiguration in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelNoSQLResourceResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)

        503: Service Unavailable - ResponseErrorResponse (Service Unavailable)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateNoSQLClusterV2.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

"""The top-level package for the AccelByte Python SDK."""

__product__ = "AccelBytePythonSDK"
__version__ = "0.85.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

from .core import AccelByteSDK

from .core import is_initialized
from .core import initialize
from .core import reset


def get_version(
    latest: bool = False,
    full: bool = False,
    **kwargs,
) -> str:
    result = f"{__product__} {__version__}" if full else __version__

    if latest:
        # noinspection PyBroadException
        try:
            import requests

            response = requests.get(url=f"https://pypi.org/pypi/accelbyte-py-sdk/json")
            if response.ok:
                response_json = response.json()
                latest_version = response_json.get("info", {}).get("version")
                if latest_version is not None and __version__ != latest_version:
                    result += f" (latest: {latest_version})"
        except Exception:
            pass  # Best-effort version check: ignore all errors silently.

    return result



# Copyright (c) 2025 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.

from typing import Any, Dict, Optional

from ...core import (
    SDK,
    AccelByteSDK,
)

from ...api import iam
from ...api.iam.operations import o_auth2_0 as oauth2

from ._login_const import DEFAULT_REFRESH_RATE


def login_refresh_internal(
    refresh_token: str,
    token_type: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    sdk = sdk or SDK

    token, error = iam.token_grant_v3(
        grant_type=oauth2.TokenGrantV3GrantTypeEnum.REFRESH_TOKEN,
        refresh_token=refresh_token,
        x_additional_headers=x_additional_headers,
        sdk=sdk,
        **kwargs,
    )
    if error:
        return None, error

    assert token, "Token value missing!"

    _, error = sdk.set_token(token=token, type=token_type)
    if error:
        return None, error

    return token, None


async def login_refresh_async_internal(
    refresh_token: str,
    token_type: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    sdk = sdk or SDK

    token, error = await iam.token_grant_v3_async(
        grant_type=oauth2.TokenGrantV3GrantTypeEnum.REFRESH_TOKEN,
        refresh_token=refresh_token,
        x_additional_headers=x_additional_headers,
        sdk=sdk,
        **kwargs,
    )
    if error:
        return None, error

    assert token, "Token value missing!"

    _, error = sdk.set_token(token=token, type=token_type)
    if error:
        return None, error

    return token, None


def try_refresh_login_internal(
    refresh_rate: float = DEFAULT_REFRESH_RATE,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    token_repo = sdk.get_token_repository(raise_when_none=False)
    if token_repo is None:
        return None

    if token_repo.has_token_expired(multiplier=refresh_rate):
        refresh_token = token_repo.get_refresh_token()
        if not refresh_token:
            return None

        new_token, error = login_refresh_internal(
            refresh_token=refresh_token,
            token_type=token_repo.get_token_type(),
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )
        if error:
            return None
        assert new_token, "Token value missing!"
        return new_token
    else:
        token = token_repo.get_token()


async def try_refresh_login_async_internal(
    refresh_rate: float = DEFAULT_REFRESH_RATE,
    x_additional_headers: Optional[Dict[str, str]] = None,
    sdk: Optional[AccelByteSDK] = None,
    **kwargs,
):
    token_repo = sdk.get_token_repository(raise_when_none=False)
    if token_repo is None:
        return None

    if token_repo.has_token_expired(multiplier=refresh_rate):
        refresh_token = token_repo.get_refresh_token()
        if not refresh_token:
            return None

        new_token, error = await login_refresh_async_internal(
            refresh_token=refresh_token,
            token_type=token_repo.get_token_type(),
            x_additional_headers=x_additional_headers,
            sdk=sdk,
            **kwargs,
        )
        if error:
            return None
        assert new_token, "Token value missing!"
        return new_token
    else:
        return None


__all__ = [
    "login_refresh_internal",
    "login_refresh_async_internal",
    "try_refresh_login_internal",
    "try_refresh_login_async_internal",
]



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiNamespaceConfigList
from ..models import ApiPatchNamespaceConfigRequest
from ..models import ConfigmodelsNamespaceConfig
from ..models import LogconfigConfiguration
from ..models import ResponseError

from ..operations.config import AdminGetAllConfigV1
from ..operations.config import AdminGetConfigV1
from ..operations.config import AdminGetLogConfig
from ..operations.config import AdminPatchConfigV1
from ..operations.config import AdminPatchUpdateLogConfig
from ..models import LogconfigConfigurationLogLevelEnum


@same_doc_as(AdminGetAllConfigV1)
def admin_get_all_config_v1(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """admin get all namespaces config (adminGetAllConfigV1)

    Get matchmaking config of all namespaces. Will only return namespace configs than have been updated.

    Properties:
        url: /match2/v1/config

        method: GET

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ApiNamespaceConfigList (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = AdminGetAllConfigV1.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetAllConfigV1)
async def admin_get_all_config_v1_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """admin get all namespaces config (adminGetAllConfigV1)

    Get matchmaking config of all namespaces. Will only return namespace configs than have been updated.

    Properties:
        url: /match2/v1/config

        method: GET

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ApiNamespaceConfigList (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    request = AdminGetAllConfigV1.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetConfigV1)
def admin_get_config_v1(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get namespace config (adminGetConfigV1)

    Get matchmaking config of a namespaces.

    Properties:
        url: /match2/v1/config/namespaces/{namespace}

        method: GET

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ConfigmodelsNamespaceConfig (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetConfigV1.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetConfigV1)
async def admin_get_config_v1_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin get namespace config (adminGetConfigV1)

    Get matchmaking config of a namespaces.

    Properties:
        url: /match2/v1/config/namespaces/{namespace}

        method: GET

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ConfigmodelsNamespaceConfig (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetConfigV1.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetLogConfig)
def admin_get_log_config(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Log Configuration (adminGetLogConfig)

    Get Log Configuration.

    Properties:
        url: /match2/v1/admin/config/log

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - LogconfigConfiguration
    """
    request = AdminGetLogConfig.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetLogConfig)
async def admin_get_log_config_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Get Log Configuration (adminGetLogConfig)

    Get Log Configuration.

    Properties:
        url: /match2/v1/admin/config/log

        method: GET

        tags: ["Config"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - LogconfigConfiguration
    """
    request = AdminGetLogConfig.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPatchConfigV1)
def admin_patch_config_v1(
    body: ApiPatchNamespaceConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin patch update namespace config (adminPatchConfigV1)

    Patch update matchmaking config of a namespaces. Partially update matchmaking config, will only update value that defined on the request.

    Properties:
        url: /match2/v1/config/namespaces/{namespace}

        method: PATCH

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiPatchNamespaceConfigRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ConfigmodelsNamespaceConfig (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminPatchConfigV1.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPatchConfigV1)
async def admin_patch_config_v1_async(
    body: ApiPatchNamespaceConfigRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """admin patch update namespace config (adminPatchConfigV1)

    Patch update matchmaking config of a namespaces. Partially update matchmaking config, will only update value that defined on the request.

    Properties:
        url: /match2/v1/config/namespaces/{namespace}

        method: PATCH

        tags: ["Config", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiPatchNamespaceConfigRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ConfigmodelsNamespaceConfig (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminPatchConfigV1.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminPatchUpdateLogConfig)
def admin_patch_update_log_config(
    body: LogconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Log Configuration (adminPatchUpdateLogConfig)

    Update Log Configuration.

    Properties:
        url: /match2/v1/admin/config/log

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LogconfigConfiguration in body

    Responses:
        200: OK - LogconfigConfiguration
    """
    request = AdminPatchUpdateLogConfig.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminPatchUpdateLogConfig)
async def admin_patch_update_log_config_async(
    body: LogconfigConfiguration,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Patch Update Log Configuration (adminPatchUpdateLogConfig)

    Update Log Configuration.

    Properties:
        url: /match2/v1/admin/config/log

        method: PATCH

        tags: ["Config"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED LogconfigConfiguration in body

    Responses:
        200: OK - LogconfigConfiguration
    """
    request = AdminPatchUpdateLogConfig.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ModelInputValidationConfigVersion
from ..models import ModelInputValidationUpdatePayload
from ..models import ModelInputValidationsPublicResponse
from ..models import ModelInputValidationsResponse
from ..models import RestErrorResponse

from ..operations.input_validations import AdminGetInputValidations
from ..operations.input_validations import AdminGetNamespaceScopedInputValidations
from ..operations.input_validations import AdminResetInputValidations
from ..operations.input_validations import AdminResetNamespaceScopedInputValidations
from ..operations.input_validations import AdminUpdateInputValidations
from ..operations.input_validations import AdminUpdateNamespaceScopedInputValidations
from ..operations.input_validations import PublicGetInputValidationByField
from ..operations.input_validations import PublicGetInputValidations
from ..operations.input_validations import (
    PublicGetNamespaceScopedInputValidationByField,
)
from ..operations.input_validations import PublicGetNamespaceScopedInputValidations


@deprecated
@same_doc_as(AdminGetInputValidations)
def admin_get_input_validations(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Admin Get Input Validations (AdminGetInputValidations)

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations[GET]

    Properties:
        url: /iam/v3/admin/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ModelInputValidationsResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)
    """
    request = AdminGetInputValidations.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AdminGetInputValidations)
async def admin_get_input_validations_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Admin Get Input Validations (AdminGetInputValidations)

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations[GET]

    Properties:
        url: /iam/v3/admin/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ModelInputValidationsResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)
    """
    request = AdminGetInputValidations.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetNamespaceScopedInputValidations)
def admin_get_namespace_scoped_input_validations(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Get Input Validations (AdminGetNamespaceScopedInputValidations)

    Returns the list of input validation configuration.
    Supported namespace:
    - publisher namespace
    - studio namespace

    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationsResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetNamespaceScopedInputValidations.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetNamespaceScopedInputValidations)
async def admin_get_namespace_scoped_input_validations_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Get Input Validations (AdminGetNamespaceScopedInputValidations)

    Returns the list of input validation configuration.
    Supported namespace:
    - publisher namespace
    - studio namespace

    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationsResponse (OK)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminGetNamespaceScopedInputValidations.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(AdminResetInputValidations)
def admin_reset_input_validations(
    field: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Admin Reset Input Validations (AdminResetInputValidations)

    Resets input validation to the default input validation configurations.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations/{field}[DELETE]

    Properties:
        url: /iam/v3/admin/inputValidations/{field}

        method: DELETE

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    request = AdminResetInputValidations.create(
        field=field,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AdminResetInputValidations)
async def admin_reset_input_validations_async(
    field: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Admin Reset Input Validations (AdminResetInputValidations)

    Resets input validation to the default input validation configurations.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations/{field}[DELETE]

    Properties:
        url: /iam/v3/admin/inputValidations/{field}

        method: DELETE

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    request = AdminResetInputValidations.create(
        field=field,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminResetNamespaceScopedInputValidations)
def admin_reset_namespace_scoped_input_validations(
    field: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Reset Input Validations (AdminResetNamespaceScopedInputValidations)

    Resets input validation to the default input validation configurations.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations/{field}

        method: DELETE

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminResetNamespaceScopedInputValidations.create(
        field=field,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminResetNamespaceScopedInputValidations)
async def admin_reset_namespace_scoped_input_validations_async(
    field: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Reset Input Validations (AdminResetNamespaceScopedInputValidations)

    Resets input validation to the default input validation configurations.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations/{field}

        method: DELETE

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminResetNamespaceScopedInputValidations.create(
        field=field,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(AdminUpdateInputValidations)
def admin_update_input_validations(
    body: List[ModelInputValidationUpdatePayload],
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Update Input Validations (AdminUpdateInputValidations)

    Updates input validation configuration.
    Supported `field`:
    - displayName
    - password
    - username
    - email
    - avatar

    If `isCustomRegex` is set to true, `regex` parameter will be used as input validation and the other parameters will be ignored. Otherwise, `regex` parameter will be ignored and regex for input validation will be generated based on the combination of the other parameters.
    If `allowUnicode` is set to true, unicode regex pattern will be use as the input validation and the other parameters will be ignored.
    Supported `letterCase`:
    - lowercase
    - uppercase
    - mixed: uppercase and lowercase
    - any: uppercase and/or lowercase

    Flexible special character support with `allowAllSpecialCharacters`.
    If `allowAllSpecialCharacters` is set to true, `specialCharacters` will be forced to empty.
    Supported `specialCharacterLocation`:
    - anywhere
    - middle

    If `specialCharacters` is empty, `specialCharacterLocation` and `maxRepeatingSpecialCharacter` will be ignored.
    `minCharType` is used to identify how many required criteria in the regex. The supported criteria are number, letter, special character, and letter case. If set to 0 or 1, all criteria are optional. It can be set as much as the number of criteria enabled.
    If `blockedWord` is set by an admin, any user input containing a blocked word will be rejected during account creation, upgrade, or update.
    If `avatarConfig` is set, will use this config and skip all the other validation conditions.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations[PUT]

    Properties:
        url: /iam/v3/admin/inputValidations

        method: PUT

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelInputValidationUpdatePayload] in body

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    request = AdminUpdateInputValidations.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(AdminUpdateInputValidations)
async def admin_update_input_validations_async(
    body: List[ModelInputValidationUpdatePayload],
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Update Input Validations (AdminUpdateInputValidations)

    Updates input validation configuration.
    Supported `field`:
    - displayName
    - password
    - username
    - email
    - avatar

    If `isCustomRegex` is set to true, `regex` parameter will be used as input validation and the other parameters will be ignored. Otherwise, `regex` parameter will be ignored and regex for input validation will be generated based on the combination of the other parameters.
    If `allowUnicode` is set to true, unicode regex pattern will be use as the input validation and the other parameters will be ignored.
    Supported `letterCase`:
    - lowercase
    - uppercase
    - mixed: uppercase and lowercase
    - any: uppercase and/or lowercase

    Flexible special character support with `allowAllSpecialCharacters`.
    If `allowAllSpecialCharacters` is set to true, `specialCharacters` will be forced to empty.
    Supported `specialCharacterLocation`:
    - anywhere
    - middle

    If `specialCharacters` is empty, `specialCharacterLocation` and `maxRepeatingSpecialCharacter` will be ignored.
    `minCharType` is used to identify how many required criteria in the regex. The supported criteria are number, letter, special character, and letter case. If set to 0 or 1, all criteria are optional. It can be set as much as the number of criteria enabled.
    If `blockedWord` is set by an admin, any user input containing a blocked word will be rejected during account creation, upgrade, or update.
    If `avatarConfig` is set, will use this config and skip all the other validation conditions.
    **Substitute endpoint:** /iam/v3/admin/namespaces/{namespace}/inputValidations[PUT]

    Properties:
        url: /iam/v3/admin/inputValidations

        method: PUT

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelInputValidationUpdatePayload] in body

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    request = AdminUpdateInputValidations.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminUpdateNamespaceScopedInputValidations)
def admin_update_namespace_scoped_input_validations(
    body: List[ModelInputValidationUpdatePayload],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Update Input Validations (AdminUpdateNamespaceScopedInputValidations)

    Updates input validation configuration.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Supported `field`:
    - displayName
    - password
    - username
    - email
    - avatar

    If `isCustomRegex` is set to true, `regex` parameter will be used as input validation and the other parameters will be ignored. Otherwise, `regex` parameter will be ignored and regex for input validation will be generated based on the combination of the other parameters.
    If `allowUnicode` is set to true, unicode regex pattern will be use as the input validation and the other parameters will be ignored.
    Supported `letterCase`:
    - lowercase
    - uppercase
    - mixed: uppercase and lowercase
    - any: uppercase and/or lowercase

    To allow flexible non-word special characters, use `allowAllSpecialCharacters`.
    If `allowAllSpecialCharacters` is set to true, `specialCharacters` will be forced to empty.
    Supported `specialCharacterLocation`:
    - anywhere
    - middle

    If `specialCharacters` is empty, `specialCharacterLocation` and `maxRepeatingSpecialCharacter` will be ignored.
    `minCharType` is used to identify how many required criteria in the regex. The supported criteria are number, letter, special character, and letter case. If set to 0 or 1, all criteria are optional. It can be set as much as the number of criteria enabled.
    If `blockedWord` is set by an admin, any user input containing a blocked word will be rejected during account creation, upgrade, or update.
    If `avatarConfig` is set, will use this config and skip all the other validation conditions.

    These are the boundary values for string length:
    minLength: 1,
    maxLength: 256

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations

        method: PUT

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelInputValidationUpdatePayload] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdateNamespaceScopedInputValidations.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminUpdateNamespaceScopedInputValidations)
async def admin_update_namespace_scoped_input_validations_async(
    body: List[ModelInputValidationUpdatePayload],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Admin Update Input Validations (AdminUpdateNamespaceScopedInputValidations)

    Updates input validation configuration.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Supported `field`:
    - displayName
    - password
    - username
    - email
    - avatar

    If `isCustomRegex` is set to true, `regex` parameter will be used as input validation and the other parameters will be ignored. Otherwise, `regex` parameter will be ignored and regex for input validation will be generated based on the combination of the other parameters.
    If `allowUnicode` is set to true, unicode regex pattern will be use as the input validation and the other parameters will be ignored.
    Supported `letterCase`:
    - lowercase
    - uppercase
    - mixed: uppercase and lowercase
    - any: uppercase and/or lowercase

    To allow flexible non-word special characters, use `allowAllSpecialCharacters`.
    If `allowAllSpecialCharacters` is set to true, `specialCharacters` will be forced to empty.
    Supported `specialCharacterLocation`:
    - anywhere
    - middle

    If `specialCharacters` is empty, `specialCharacterLocation` and `maxRepeatingSpecialCharacter` will be ignored.
    `minCharType` is used to identify how many required criteria in the regex. The supported criteria are number, letter, special character, and letter case. If set to 0 or 1, all criteria are optional. It can be set as much as the number of criteria enabled.
    If `blockedWord` is set by an admin, any user input containing a blocked word will be rejected during account creation, upgrade, or update.
    If `avatarConfig` is set, will use this config and skip all the other validation conditions.

    These are the boundary values for string length:
    minLength: 1,
    maxLength: 256

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/inputValidations

        method: PUT

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[ModelInputValidationUpdatePayload] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20013: insufficient permissions)

        404: Not Found - RestErrorResponse (10188: input validation field not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = AdminUpdateNamespaceScopedInputValidations.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicGetInputValidationByField)
def public_get_input_validation_by_field(
    field: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Public Get Input Validation by field (PublicGetInputValidationByField)

    Returns input validation configuration by field.
    **Substitute endpoint:** /iam/v3/public/namespaces/{namespace}/inputValidations/{field}[GET]

    Properties:
        url: /iam/v3/public/inputValidations/{field}

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationConfigVersion (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = PublicGetInputValidationByField.create(
        field=field,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicGetInputValidationByField)
async def public_get_input_validation_by_field_async(
    field: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Public Get Input Validation by field (PublicGetInputValidationByField)

    Returns input validation configuration by field.
    **Substitute endpoint:** /iam/v3/public/namespaces/{namespace}/inputValidations/{field}[GET]

    Properties:
        url: /iam/v3/public/inputValidations/{field}

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationConfigVersion (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = PublicGetInputValidationByField.create(
        field=field,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(PublicGetInputValidations)
def public_get_input_validations(
    default_on_empty: Optional[bool] = None,
    language_code: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validations (PublicGetInputValidations)

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.
    **Substitute endpoint:** /iam/v3/public/namespaces/{namespace}/inputValidations[GET]

    Properties:
        url: /iam/v3/public/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        default_on_empty: (defaultOnEmpty) OPTIONAL bool in query

        language_code: (languageCode) OPTIONAL str in query

    Responses:
        200: OK - ModelInputValidationsPublicResponse (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = PublicGetInputValidations.create(
        default_on_empty=default_on_empty,
        language_code=language_code,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(PublicGetInputValidations)
async def public_get_input_validations_async(
    default_on_empty: Optional[bool] = None,
    language_code: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validations (PublicGetInputValidations)

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.
    **Substitute endpoint:** /iam/v3/public/namespaces/{namespace}/inputValidations[GET]

    Properties:
        url: /iam/v3/public/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        default_on_empty: (defaultOnEmpty) OPTIONAL bool in query

        language_code: (languageCode) OPTIONAL str in query

    Responses:
        200: OK - ModelInputValidationsPublicResponse (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = PublicGetInputValidations.create(
        default_on_empty=default_on_empty,
        language_code=language_code,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetNamespaceScopedInputValidationByField)
def public_get_namespace_scoped_input_validation_by_field(
    field: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validation by field (PublicGetNamespaceScopedInputValidationByField)

    Returns input validation configuration by field.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/inputValidations/{field}

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationConfigVersion (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetNamespaceScopedInputValidationByField.create(
        field=field,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetNamespaceScopedInputValidationByField)
async def public_get_namespace_scoped_input_validation_by_field_async(
    field: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validation by field (PublicGetNamespaceScopedInputValidationByField)

    Returns input validation configuration by field.
    Supported namespace:
    - publisher namespace
    - studio namespace

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/inputValidations/{field}

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        field: (field) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ModelInputValidationConfigVersion (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetNamespaceScopedInputValidationByField.create(
        field=field,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetNamespaceScopedInputValidations)
def public_get_namespace_scoped_input_validations(
    default_on_empty: Optional[bool] = None,
    language_code: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validations (PublicGetNamespaceScopedInputValidations)

    Supported namespace:
    - publisher namespace
    - studio namespace

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        default_on_empty: (defaultOnEmpty) OPTIONAL bool in query

        language_code: (languageCode) OPTIONAL str in query

    Responses:
        200: OK - ModelInputValidationsPublicResponse (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetNamespaceScopedInputValidations.create(
        default_on_empty=default_on_empty,
        language_code=language_code,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetNamespaceScopedInputValidations)
async def public_get_namespace_scoped_input_validations_async(
    default_on_empty: Optional[bool] = None,
    language_code: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Public Get Input Validations (PublicGetNamespaceScopedInputValidations)

    Supported namespace:
    - publisher namespace
    - studio namespace

    Returns the list of input validation configuration.
    `regex` parameter will be returned if `isCustomRegex` is true. Otherwise, it will be empty.

    Properties:
        url: /iam/v3/public/namespaces/{namespace}/inputValidations

        method: GET

        tags: ["InputValidations"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        default_on_empty: (defaultOnEmpty) OPTIONAL bool in query

        language_code: (languageCode) OPTIONAL str in query

    Responses:
        200: OK - ModelInputValidationsPublicResponse (OK)

        404: Not Found - (Data not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = PublicGetNamespaceScopedInputValidations.create(
        default_on_empty=default_on_empty,
        language_code=language_code,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Inventory Service Early Access

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.apimodels_consume_item import ApimodelsConsumeItem
from ..models.apimodels_create_item import ApimodelsCreateItem
from ..models.apimodels_remove_item import ApimodelsRemoveItem
from ..models.apimodels_update_item import ApimodelsUpdateItem


class ApimodelsOperation(Model):
    """Apimodels operation (apimodels.Operation)

    Properties:
        consume_items: (consumeItems) REQUIRED List[ApimodelsConsumeItem]

        create_items: (createItems) REQUIRED List[ApimodelsCreateItem]

        remove_items: (removeItems) REQUIRED List[ApimodelsRemoveItem]

        target_user_id: (targetUserId) REQUIRED str

        update_items: (updateItems) REQUIRED List[ApimodelsUpdateItem]
    """

    # region fields

    consume_items: List[ApimodelsConsumeItem]  # REQUIRED
    create_items: List[ApimodelsCreateItem]  # REQUIRED
    remove_items: List[ApimodelsRemoveItem]  # REQUIRED
    target_user_id: str  # REQUIRED
    update_items: List[ApimodelsUpdateItem]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_consume_items(
        self, value: List[ApimodelsConsumeItem]
    ) -> ApimodelsOperation:
        self.consume_items = value
        return self

    def with_create_items(self, value: List[ApimodelsCreateItem]) -> ApimodelsOperation:
        self.create_items = value
        return self

    def with_remove_items(self, value: List[ApimodelsRemoveItem]) -> ApimodelsOperation:
        self.remove_items = value
        return self

    def with_target_user_id(self, value: str) -> ApimodelsOperation:
        self.target_user_id = value
        return self

    def with_update_items(self, value: List[ApimodelsUpdateItem]) -> ApimodelsOperation:
        self.update_items = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "consume_items"):
            result["consumeItems"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.consume_items
            ]
        elif include_empty:
            result["consumeItems"] = []
        if hasattr(self, "create_items"):
            result["createItems"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.create_items
            ]
        elif include_empty:
            result["createItems"] = []
        if hasattr(self, "remove_items"):
            result["removeItems"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.remove_items
            ]
        elif include_empty:
            result["removeItems"] = []
        if hasattr(self, "target_user_id"):
            result["targetUserId"] = str(self.target_user_id)
        elif include_empty:
            result["targetUserId"] = ""
        if hasattr(self, "update_items"):
            result["updateItems"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.update_items
            ]
        elif include_empty:
            result["updateItems"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        consume_items: List[ApimodelsConsumeItem],
        create_items: List[ApimodelsCreateItem],
        remove_items: List[ApimodelsRemoveItem],
        target_user_id: str,
        update_items: List[ApimodelsUpdateItem],
        **kwargs,
    ) -> ApimodelsOperation:
        instance = cls()
        instance.consume_items = consume_items
        instance.create_items = create_items
        instance.remove_items = remove_items
        instance.target_user_id = target_user_id
        instance.update_items = update_items
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsOperation:
        instance = cls()
        if not dict_:
            return instance
        if "consumeItems" in dict_ and dict_["consumeItems"] is not None:
            instance.consume_items = [
                ApimodelsConsumeItem.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["consumeItems"]
            ]
        elif include_empty:
            instance.consume_items = []
        if "createItems" in dict_ and dict_["createItems"] is not None:
            instance.create_items = [
                ApimodelsCreateItem.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["createItems"]
            ]
        elif include_empty:
            instance.create_items = []
        if "removeItems" in dict_ and dict_["removeItems"] is not None:
            instance.remove_items = [
                ApimodelsRemoveItem.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["removeItems"]
            ]
        elif include_empty:
            instance.remove_items = []
        if "targetUserId" in dict_ and dict_["targetUserId"] is not None:
            instance.target_user_id = str(dict_["targetUserId"])
        elif include_empty:
            instance.target_user_id = ""
        if "updateItems" in dict_ and dict_["updateItems"] is not None:
            instance.update_items = [
                ApimodelsUpdateItem.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["updateItems"]
            ]
        elif include_empty:
            instance.update_items = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsOperation]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsOperation]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsOperation, List[ApimodelsOperation], Dict[Any, ApimodelsOperation]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "consumeItems": "consume_items",
            "createItems": "create_items",
            "removeItems": "remove_items",
            "targetUserId": "target_user_id",
            "updateItems": "update_items",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "consumeItems": True,
            "createItems": True,
            "removeItems": True,
            "targetUserId": True,
            "updateItems": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import RestErrorResponse

from ..operations.sso import LoginSSOClient
from ..operations.sso import LogoutSSOClient


@same_doc_as(LoginSSOClient)
def login_sso_client(
    platform_id: str,
    payload: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Login to SSO client with provided platformId (LoginSSOClient)

    Redirects the user to the SSO client's login page for the specified platform. An optional 'payload' query parameter can be passed with key-value data from the SSO client.

    Properties:
        url: /iam/v3/sso/{platformId}

        method: GET

        tags: ["SSO"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        platform_id: (platformId) REQUIRED str in path

        payload: (payload) OPTIONAL str in query

    Responses:
        200: OK - (OK)
    """
    request = LoginSSOClient.create(
        platform_id=platform_id,
        payload=payload,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(LoginSSOClient)
async def login_sso_client_async(
    platform_id: str,
    payload: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Login to SSO client with provided platformId (LoginSSOClient)

    Redirects the user to the SSO client's login page for the specified platform. An optional 'payload' query parameter can be passed with key-value data from the SSO client.

    Properties:
        url: /iam/v3/sso/{platformId}

        method: GET

        tags: ["SSO"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        platform_id: (platformId) REQUIRED str in path

        payload: (payload) OPTIONAL str in query

    Responses:
        200: OK - (OK)
    """
    request = LoginSSOClient.create(
        platform_id=platform_id,
        payload=payload,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(LogoutSSOClient)
def logout_sso_client(
    platform_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Logout (LogoutSSOClient)

    Logs out the user's session on a platform that was authenticated using SSO.

    Supported platforms:
    - discourse

    Properties:
        url: /iam/v3/sso/{platformId}/logout

        method: POST

        tags: ["SSO"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        platform_id: (platformId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        404: Not Found - RestErrorResponse (Not Found)

        422: Unprocessable Entity - RestErrorResponse (Unprocessable Entity)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = LogoutSSOClient.create(
        platform_id=platform_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(LogoutSSOClient)
async def logout_sso_client_async(
    platform_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Logout (LogoutSSOClient)

    Logs out the user's session on a platform that was authenticated using SSO.

    Supported platforms:
    - discourse

    Properties:
        url: /iam/v3/sso/{platformId}/logout

        method: POST

        tags: ["SSO"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        platform_id: (platformId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        404: Not Found - RestErrorResponse (Not Found)

        422: Unprocessable Entity - RestErrorResponse (Unprocessable Entity)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """
    request = LogoutSSOClient.create(
        platform_id=platform_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class LogLevelEnum(StrEnum):
    DEBUG = "debug"
    ERROR = "error"
    FATAL = "fatal"
    INFO = "info"
    PANIC = "panic"
    TRACE = "trace"
    WARNING = "warning"


class LogconfigConfiguration(Model):
    """Logconfig configuration (logconfig.Configuration)

    Properties:
        log_level: (logLevel) OPTIONAL Union[str, LogLevelEnum]
    """

    # region fields

    log_level: Union[str, LogLevelEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_log_level(self, value: Union[str, LogLevelEnum]) -> LogconfigConfiguration:
        self.log_level = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "log_level"):
            result["logLevel"] = str(self.log_level)
        elif include_empty:
            result["logLevel"] = Union[str, LogLevelEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, log_level: Optional[Union[str, LogLevelEnum]] = None, **kwargs
    ) -> LogconfigConfiguration:
        instance = cls()
        if log_level is not None:
            instance.log_level = log_level
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> LogconfigConfiguration:
        instance = cls()
        if not dict_:
            return instance
        if "logLevel" in dict_ and dict_["logLevel"] is not None:
            instance.log_level = str(dict_["logLevel"])
        elif include_empty:
            instance.log_level = Union[str, LogLevelEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, LogconfigConfiguration]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[LogconfigConfiguration]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        LogconfigConfiguration,
        List[LogconfigConfiguration],
        Dict[Any, LogconfigConfiguration],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "logLevel": "log_level",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "logLevel": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "logLevel": [
                "debug",
                "error",
                "fatal",
                "info",
                "panic",
                "trace",
                "warning",
            ],
        }

    # endregion static methods
